//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[FuroChanceShantenArgs](index.md)/[allowChi](allow-chi.md)

# allowChi

[common]\
val [allowChi](allow-chi.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = true

#### Parameters

common

| | |
|---|---|
| allowChi | 是否允许吃 |
